# Navgator

![N|Solid](https://img.shields.io/badge/price-Free-green.svg) ![N|Solid](https://img.shields.io/badge/python-%3E%3D3.7-blue.svg)

[![N|Solid](https://www.python.org/static/community_logos/python-powered-w-100x40.png)](https://www.python.org)

>**Navgator** is a multi-paned multi-tabbed file manager

**New in v0.4**
```sh
++ Icons View
++ List View
```

**New in v0.3**
```sh
++ Thumbnails
```

**New in v0.2**
```sh
++ Aliases
```

```sh
+ Multi Pane Browser
+ Multiple tabs can be opened in each pane
+ Individual Tree per Pane and Common Tree across Panes
+ Different Address Bar per pane
+ BreadCrumbs
+ File Management Basics
    Basic Toolbar with back and forward buttons
    Checkbox Selection
+ Edit Menu
    New File (Ctrl+N)
    New Folder (Ctrl+Shift+n)
    Inline Rename (F2)
    Cut (Ctrl+X)
    Copy (Ctrl+C)
    Paste (Ctrl+V)
    Send to Trash (Del)
    Delete (Shift+Del)
    Delete current folder and go up. (Ctrl+Del)
+ Checkbox selections 
+ Selections submenu (inside Edit Menu)
    Select All (Ctrl+A)
    Clear All (Ctrl+Shift+A)
    Invert Selection(Ctrl+Shift+I)
+ Items can be selected using selection rectangle
    Ctrl and Shift can be used for extended selection.
    Ctrl will toggle any overlapping selections while shift won't
+ Tabs Menu
    New tab (Ctrl+T)
    Close Tab (Ctrl+W)
    Rename Tab (Ctrl+E)
    Select Next Tab (Ctrl+Tab)
    Select Previous (Ctrl+Shift+Tab)
    Close Left Tabs
    Close Right Tabs
    Close Other Tabs
+ Live Filter Box per tab (Escape removes filter from active pane)
+ Drag and Drop
+ User Commands can be added via JSON file
+ Move on Rename: 
+ Sort folders to top
+ Active tab is colored
+ Lazy loading - Inactive tabs aren't loaded or refreshed
+ Main Tree, Panes and Status Bar can be hidden
+ Double click on empty space or non-name columns to go up.
+ Remembers and restores previous session
```

### Installation

```sh
pip install navgator
```

### Todos

 - Improve settings dialog

License
----
MIT
